@@ -23,6 +23,7 @@ from .exceptions import DSLibraryDataFormatException, DSLibraryException
 from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
 from .utils.connect import connect_to_database, dataframe_to_sql, db_conn_flavor
+from .utils.csp_connect import connect_to_csp
 from .utils.dbconn import sql_enquote_id
 from .utils.df_utils import CloseAfterIteration, load_dataframe_from_sql, LoadStrategy
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
@@ -302,6 +303,8 @@ class DSLibrary(object):
         if system_type == "nosql":
             library = kwargs.pop("library", None)
             return connect_to_nosql(uri=uri, library=library, for_write=for_write, **kwargs)
+        if system_type == "csp":
+            return connect_to_csp(service=resource_name, for_write=for_write, **kwargs)
         raise ValueError(f"Unsupported system_type: {system_type}")
 
     def get_filesystem_connection(self, resource_name: str, for_write: bool=False, **kwargs):
@@ -339,6 +342,15 @@ class DSLibrary(object):
         """
         return self._get_system_connection("nosql", resource_name, for_write, **kwargs)
 
+    def get_csp_connection(self, resource_name: str, for_write: bool=False, **kwargs):
+        """
+        Returns a native interface to a CSP service.  For example, returns a boto3 client for s3, sagemaker, etc..
+
+        :param resource_name:   Which service to access.
+        :param for_write:       True to enable write operations.  (Ignored for now.)
+        """
+        return self._get_system_connection("csp", resource_name, for_write, **kwargs)
+
     def log_param(self, key: str, value):
         """
         Log a supplied parameter.
@@ -825,10 +837,12 @@ class DSLibrary(object):
             run_data - True to read using open_run_data()
             dask - True to load into a dask dataframe, or an integer to load into dask if file size is >= to threshold.
             sniff_only - True to do all format analysis and return a LoadStrategy, rather than a dataframe
+            sniff_opener - A custom file open method for sniffing
 
         :param resource_name:   The name of an input resource, or of a local file, or the URI of an external resource.
         """
         sniff_only = kwargs.pop("sniff_only", None)
+        sniff_opener = kwargs.pop("sniff_opener", None)
         # look up pre-supplied data
         # do translation of named resources
         if isinstance(resource_name, str):
@@ -913,18 +927,20 @@ class DSLibrary(object):
             if sniff_only:
                 return LoadStrategy(predefined=df)
             return df
-        # sample-taker
+        # sample-taker and size measurer
+        # - use 'sniff_opener' if provided
+        sample_opener = sniff_opener or use_opener
         def sampler():
             sample_size = open_args.pop("sample_size", None) or 30000
             if sample_size < 0:
                 return
             try:
-                with use_opener(uri, mode='rb', **open_args) as f_r:
+                with sample_opener(uri, mode='rb', **open_args) as f_r:
                     return f_r.read(sample_size)
             except IsADirectoryError:
                 pass
         def sizer():
-            with use_opener(resource_name, mode='rb', **open_args) as f_r:
+            with sample_opener(resource_name, mode='rb', **open_args) as f_r:
                 if not hasattr(f_r, "seek") or not f_r.seekable():
                     return
                 try:
