@@ -1,7 +1,8 @@
 import unittest
 import pandas
 
-from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2
+from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2, \
+    connect_to_database
 
 
 class TestConnect(unittest.TestCase):
@@ -58,3 +59,9 @@ class TestConnect(unittest.TestCase):
         class MyPostGresDriver(object):
             pass
         self.assertEqual(db_conn_flavor(MyPostGresDriver()), "postgres")
+
+    def test_sniff__pg(self):
+        strategy = connect_to_database("postgres://u:p@host:1234/database", sniff_only=True)
+        self.assertEqual(strategy.open_args, {'dsn': 'dbname=database host=host password=p port=1234 user=u'})
+        import psycopg2
+        self.assertIs(strategy.opener, psycopg2.connect)
